import os
from tempfile import TemporaryDirectory

from thehive4py import TheHiveApi

hive = TheHiveApi(url="http://localhost:9000", apikey="h1v3b33")

case_to_enrich = hive.case.create(
    case={
        "title": "case to enrich",
        "description": "a case to enrich with task and task log",
    },
)

case_task_to_enrich = hive.task.create(
    case_id=case_to_enrich["_id"],
    task={"title": "a task to enrich with a task log and attachment"},
)

with TemporaryDirectory() as tmpdir:
    task_log_attachment_filepath = os.path.join(tmpdir, "task_log_attachment.txt")
    with open(task_log_attachment_filepath, "w") as attachment_file:
        attachment_file.write("attachment content")

    case_task_log = hive.task_log.create(
        task_id=case_task_to_enrich["_id"],
        task_log={
            "message": "a task log with an attachment",
            "attachments": [task_log_attachment_filepath],
        },
    )



from thehive4py import TheHiveApi

hive = TheHiveApi(url="http://localhost:9000", apikey="h1v3b33")

case = hive.case.create(
    case={
        "title": "case with a comment",
        "description": "a case to comment on",
    },
)

hive.comment.create_in_case(
    case_id=case["_id"],
    comment={"message": "what an average case to comment on"},
)



import uuid

from thehive4py import TheHiveApi
from thehive4py.types.observable import InputObservable

hive = TheHiveApi(url="thehive.example", apikey="h1v3b33")

alert_to_enrich = hive.alert.create(
    alert={
        "type": "alert-without-observables",
        "source": "example",
        "sourceRef": uuid.uuid4().hex,
        "title": "alert without observables",
        "description": "alert without observables",
    }
)

simple_observable: InputObservable = {
    "dataType": "domain",
    "data": "example.com",
}
hive.alert.create_observable(
    alert_id=alert_to_enrich["_id"],
    observable=simple_observable,
)


bulk_observable: InputObservable = {
    "dataType": "domain",
    "data": ["1.example.com", "2.example.com"],
}
hive.alert.create_observable(
    alert_id=alert_to_enrich["_id"],
    observable=bulk_observable,
)


mixed_observables: list[InputObservable] = [
    {"dataType": "ip", "data": "1.2.3.4"},
    {"dataType": "domain", "data": "example.com"},
]
for observable in mixed_observables:
    hive.alert.create_observable(
        alert_id=alert_to_enrich["_id"],
        observable=observable,
    )



from typing import List

from thehive4py.client import TheHiveApi
from thehive4py.query.filters import Id
from thehive4py.types.case import OutputCase
from thehive4py.types.observable import OutputObservable


class TestCortexEndpoint:
    def test_create_and_get_analyzer_job(
        self, thehive: TheHiveApi, test_observable: OutputObservable
    ):
        created_analyzer_job = thehive.cortex.create_analyzer_job(
            job={
                "analyzerId": "example",
                "cortexId": "cortex",
                "artifactId": test_observable["_id"],
            }
        )
        assert created_analyzer_job["_type"] == "case_artifact_job"
        fetched_analyzer_job = thehive.cortex.get_analyzer_job(
            job_id=created_analyzer_job["_id"]
        )
        assert created_analyzer_job["_id"] == fetched_analyzer_job["_id"]

    def test_create_and_find_analyzer_job(
        self, thehive: TheHiveApi, test_observable: OutputObservable
    ):
        created_analyzer_job = thehive.cortex.create_analyzer_job(
            job={
                "analyzerId": "dummy-analyzer",
                "cortexId": "dummy-cortex",
                "artifactId": test_observable["_id"],
            }
        )

        found_analyzer_jobs = thehive.cortex.find_analyzer_jobs(
            filters=Id(id=created_analyzer_job["_id"])
        )

        assert len(found_analyzer_jobs) == 1
        assert found_analyzer_jobs[0]["_id"] == created_analyzer_job["_id"]

    def test_create_analyzer_jobs_in_bulk(
        self, thehive: TheHiveApi, test_observables: List[OutputObservable]
    ):
        created_analyzer_jobs = thehive.cortex.bulk_create_analyzer_jobs(
            jobs=[
                {
                    "analyzerId": "dummy-analyzer",
                    "cortexId": "dummy-cortex",
                    "artifactId": observable["_id"],
                }
                for observable in test_observables
            ]
        )

        assert len(created_analyzer_jobs) == 2
        for job in created_analyzer_jobs:
            assert job["_type"] == "case_artifact_job"

    def test_list_analyzers(self, thehive: TheHiveApi):
        analyzers = thehive.cortex.list_analyzers()
        assert analyzers == []

    def test_list_analyzers_by_type(self, thehive: TheHiveApi):
        data_type = "mail"
        analyzers = thehive.cortex.list_analyzers_by_type(data_type=data_type)
        assert analyzers == []

    def test_list_responders(self, thehive: TheHiveApi, test_case: OutputCase):
        responders = thehive.cortex.list_responders(
            entity_type="case", entity_id=test_case["_id"]
        )
        assert responders == []



import importlib
import runpy
from pathlib import Path

import pytest

from thehive4py import TheHiveApi

_examples_dir = Path(__file__).parent.parent / "examples"
_excluded_example_paths = []
_example_paths = sorted(
    [
        example_path
        for example_path in _examples_dir.rglob("*.py")
        if example_path not in _excluded_example_paths
    ]
)


def _patch_thehiveapi_symbol(monkeypatch: pytest.MonkeyPatch, thehive: TheHiveApi):
    """Patch TheHiveApi symbol in thehive4py modules to return the test client."""

    # Patch the package-level symbol so "from thehive4py import TheHiveApi" yields our test client
    thehive4py_lib = importlib.import_module("thehive4py")
    monkeypatch.setattr(
        thehive4py_lib, "TheHiveApi", lambda *a, **k: thehive, raising=False
    )

    # Also patch the client module symbol in case examples import from thehive4py.client
    try:
        thehive4py_client_mod = importlib.import_module("thehive4py.client")
        monkeypatch.setattr(
            thehive4py_client_mod,
            "TheHiveApi",
            lambda: thehive,
            raising=False,
        )
    except ModuleNotFoundError:
        # ignore if client module isn't present in this environment
        pass


@pytest.mark.parametrize(
    "example_path",
    _example_paths,
    ids=[
        str(example_path.relative_to(_examples_dir)) for example_path in _example_paths
    ],
)
def test_examples(
    example_path: Path, thehive: TheHiveApi, monkeypatch: pytest.MonkeyPatch
):
    """Execute each example file and consider it correct if exits without error.

    The global TheHiveApi symbol is patched so examples that do:
        from thehive4py import TheHiveApi
    or
        from thehive4py.client import TheHiveApi
    will receive the test client (thehive fixture) instead of creating a real client.
    """

    _patch_thehiveapi_symbol(monkeypatch, thehive)

    # Run the example as a script; use __main__ so top-level guards run as expected
    try:
        runpy.run_path(str(example_path), run_name="__main__")
    except Exception as exc:
        pytest.fail(f"Example {example_path} raised an exception: {exc}")



import uuid

from thehive4py import TheHiveApi

hive = TheHiveApi(url="http://localhost:9000", apikey="h1v3b33")

alert_to_comment = hive.alert.create(
    alert={
        "type": "comment-on-alert",
        "source": "tutorial",
        "sourceRef": uuid.uuid4().hex,
        "title": "alert with a comment",
        "description": "an alert to comment on",
    },
)

hive.comment.create_in_alert(
    alert_id=alert_to_comment["_id"],
    comment={"message": "what an average alert to comment on"},
)
